PatchRequest class abstract
Constructors
Properties
- baseUrl → String
-
Eg. https://api.example.com
finalinherited
- body → Payload
-
no setter
- endpoint → String
-
Eg. /users
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- headers → Headers
-
Headers to be sent with the request
finalinherited
- queryParameters → QueryParameters
-
Query parameters to be sent with the request
Eg. {'page': '1', 'limit': '10'}
will be converted to
?page=1&limit=10finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeout → Duration
-
Timeout duration for the request
finalinherited
- url → String
-
Computed full URL including base URL, endpoint, and query parameters
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited